@@ -2,8 +2,8 @@ from django.urls import path
 
 from . import views
 
-app_name = 'rbac'
+app_name = "rbac"
 
 urlpatterns = [
-	path('roles/', views.Roles.as_view(), name='roles'),
+    path("roles/", views.Roles.as_view(), name="roles"),
 ]
